pub struct Channel { /* private fields */ }Expand description
Represents a communication channel with a specific recipient.
Implementations
Sourceimpl Channel
impl Channel
Sourcepub async fn send_private_message(&self, message: &str) -> bool
pub async fn send_private_message(&self, message: &str) -> bool
pub async fn send_reaction(&self, reference_id: String, emoji: String) -> bool
pub async fn send_typing_indicator(&self) -> bool
Sourcepub async fn send_private_file(&self, file: Option<AttachmentFile>) -> bool
pub async fn send_private_file(&self, file: Option<AttachmentFile>) -> bool
Sends a private file to the recipient.
This function handles file encryption, uploads the file to a server, and sends a notification to the recipient with the file information.
Arguments
file- The file to send, wrapped in an Option.
Returns
true if the file was sent successfully, false otherwise.